<?php

namespace Cert\Certifications\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Cert\Certifications\Http\Requests\CertificationsAdminRequest;
use Cert\Certifications\Interfaces\CertificationsRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class CertificationsAdminController extends AdminController
{
    /**
     * Initialize certifications controller.
     *
     * @param type CertificationsRepositoryInterface $certifications
     *
     * @return type
     */
    public function __construct(CertificationsRepositoryInterface $certifications)
    {
        $this->model = $certifications;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(CertificationsAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('certifications.certifications.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('certifications::certifications.names').' :: ');

        return $this->theme->of('certifications::admin.certifications.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(CertificationsAdminRequest $request, $id)
    {
        $certifications = $this->model->find($id);

        if (empty($certifications)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('certifications::admin.certifications.new');
        }

        if ($request->wantsJson()) {
            return $certifications;
        }

        Former::populate($certifications);

        return view('certifications::admin.certifications.show', compact('certifications'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(CertificationsAdminRequest $request)
    {
        $certifications = $this->model->findOrNew(0);
        Former::populate($certifications);

        return view('certifications::admin.certifications.create', compact('certifications'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CertificationsAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $certifications = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('certifications::certifications.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(CertificationsAdminRequest $request, $id)
    {
        $certifications = $this->model->find($id);

        Former::populate($certifications);

        return view('certifications::admin.certifications.edit', compact('certifications'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(CertificationsAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $certifications = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('certifications::certifications.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(CertificationsAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('certifications::certifications.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
